@@ -5,7 +5,7 @@ use Moose::Role;
 requires qw/write_integer write_long/;
 
 use DateTime;
-use DateTime::Format::Strptime;
+#use DateTime::Format::Strptime;
 use DateTime::Format::Epoch;
 
 sub write_date  {    #{{{
@@ -29,7 +29,7 @@ sub write_date  {    #{{{
         $time =~ s/L/d/;
     }
     else {
-        $time =~ s/^L/d/;
+        $time =~ s/^L/\x4a/;
         $time =~ s/^I/\x4b/;
 
     }
