@@ -36,12 +36,12 @@ sub write_double {    #{{{
     my $compare_with = $double < 0 ? ceil($double) : floor($double);
     if ( $double eq $compare_with ) {
         $hessian_string =
-        $double == 0 ? "\x67"    :
-        $double == 1 ? "\x68"    :
+        $double == 0 ? "\x5b"    :
+        $double == 1 ? "\x5c"    :
              $double > -129
-          && $double < 128 ? "\x69" . _write_single_octet_float($double)
+          && $double < 128 ? "\x5d" . _write_single_octet_float($double)
           : $double > -32769
-          && $double < 32768 ? "\x6a" . _write_double_octet_float($double)
+          && $double < 32768 ? "\x5e" . _write_double_octet_float($double)
           :                    "D" . _write_full_double($double);
 
     }
